@@ -13,9 +13,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import base64
-import binascii
-import json
+import datetime
+from oslo_serialization import base64 as oslo_base64
+from oslo_serialization import jsonutils
+import six
 import sys
 import testtools
 import time
@@ -40,7 +41,7 @@ admin_b = CONF.rbac_users.admin_b
 
 def get_pem_content(pem):
     b64_content = translations.get_pem_components(pem)[1]
-    return base64.b64decode(b64_content)
+    return oslo_base64.decode_as_bytes(b64_content)
 
 
 def get_private_key_req():
@@ -50,7 +51,7 @@ def get_private_key_req():
             'algorithm': 'rsa',
             'bit_length': 2048,
             'secret_type': 'private',
-            'payload': base64.b64encode(keys.get_private_key_pem())}
+            'payload': oslo_base64.encode_as_bytes(keys.get_private_key_pem())}
 
 
 def get_public_key_req():
@@ -60,7 +61,7 @@ def get_public_key_req():
             'algorithm': 'rsa',
             'bit_length': 2048,
             'secret_type': 'public',
-            'payload': base64.b64encode(keys.get_public_key_pem())}
+            'payload': oslo_base64.encode_as_bytes(keys.get_public_key_pem())}
 
 
 def get_certificate_req():
@@ -70,7 +71,7 @@ def get_certificate_req():
             'algorithm': 'rsa',
             'bit_length': 2048,
             'secret_type': 'certificate',
-            'payload': base64.b64encode(keys.get_certificate_pem())}
+            'payload': oslo_base64.encode_as_bytes(keys.get_certificate_pem())}
 
 
 def get_passphrase_req():
@@ -83,7 +84,7 @@ def get_passphrase_req():
 def get_default_data():
     return {
         "name": "AES key",
-        "expiration": "2018-02-28T19:14:44.180394",
+        "expiration": "2020-02-28T19:14:44.180394",
         "algorithm": "aes",
         "bit_length": 256,
         "mode": "cbc",
@@ -94,7 +95,7 @@ def get_default_data():
 
 
 def get_default_payload():
-    return "AQIDBAUGBwgBAgMEBQYHCAECAwQFBgcIAQIDBAUGBwg="
+    return b"AQIDBAUGBwgBAgMEBQYHCAECAwQFBgcIAQIDBAUGBwg="
 
 
 @utils.parameterized_test_case
@@ -134,7 +135,7 @@ class SecretsTestCase(base.TestCase):
 
         self.default_secret_create_two_phase_data = {
             "name": "AES key",
-            "expiration": "2018-02-28T19:14:44.180394",
+            "expiration": "2020-02-28T19:14:44.180394",
             "algorithm": "aes",
             "bit_length": 256,
             "mode": "cbc",
@@ -144,10 +145,6 @@ class SecretsTestCase(base.TestCase):
         self.behaviors.delete_all_created_secrets()
         super(SecretsTestCase, self).tearDown()
 
-    def _cleanup_all_secrets(self):
-        for user_name in self.client.get_all_functional_test_user_names():
-            self.behaviors.delete_all_secrets_for_user(user_name=user_name)
-
     @testcase.attr('negative')
     def test_secret_create_with_only_content_type_no_payload(self):
         """Create secret with valid content type but no payload."""
@@ -226,8 +223,8 @@ class SecretsTestCase(base.TestCase):
             payload_content_type='',
             omit_headers=['Accept'])
         self.assertEqual(200, get_resp.status_code)
-        self.assertIn(test_model.payload,
-                      binascii.b2a_base64(get_resp.content))
+        self.assertEqual(test_model.payload,
+                         oslo_base64.encode_as_bytes(get_resp.content))
 
     @testcase.attr('negative')
     def test_secret_delete_doesnt_exist(self):
@@ -297,7 +294,7 @@ class SecretsTestCase(base.TestCase):
         """
         test_model = secret_models.SecretModel(
             **self.default_secret_create_data)
-        test_model.payload = str(self.oversized_payload)
+        test_model.payload = self.oversized_payload
 
         resp, secret_ref = self.behaviors.create_secret(test_model)
         self.assertEqual(413, resp.status_code)
@@ -399,11 +396,11 @@ class SecretsTestCase(base.TestCase):
 
         Launchpad bug #1315498.
         """
-        oversized_payload = bytearray().zfill(self.max_payload_size + 1)
+        oversized_payload = bytearray(self.oversized_payload)
 
         # put a value in the middle of the data that does not have a UTF-8
-        # code point.  Using // to be python3-friendly.
-        oversized_payload[self.max_payload_size // 2] = b'\xb0'
+        # code point.  Using // and 176 to be python3-friendly.
+        oversized_payload[self.max_payload_size // 2] = 176  # 0xb0
 
         test_model = secret_models.SecretModel(
             **self.default_secret_create_two_phase_data)
@@ -415,7 +412,7 @@ class SecretsTestCase(base.TestCase):
             secret_ref=secret_ref,
             payload_content_type='application/octet-stream',
             payload_content_encoding='base64',
-            payload=str(oversized_payload))
+            payload=oversized_payload)
         self.assertEqual(413, put_resp.status_code)
 
     @testcase.attr('negative')
@@ -490,7 +487,7 @@ class SecretsTestCase(base.TestCase):
             **self.default_secret_create_two_phase_data)
         test_model.payload_content_encoding = 'base64'
         test_model.payload_content_type = 'application/octet-stream'
-        test_model.payload = base64.b64encode('abcdef')
+        test_model.payload = oslo_base64.encode_as_bytes('abcdef')
 
         resp, secret_ref = self.behaviors.create_secret(test_model)
         self.assertEqual(201, resp.status_code)
@@ -500,8 +497,8 @@ class SecretsTestCase(base.TestCase):
             payload_content_type=test_model.payload_content_type,
             payload_content_encoding=test_model.payload_content_encoding)
         self.assertEqual(200, get_resp.status_code)
-        self.assertIn(test_model.payload,
-                      binascii.b2a_base64(get_resp.content))
+        self.assertEqual(test_model.payload,
+                         oslo_base64.encode_as_bytes(get_resp.content))
 
     @testcase.attr('negative')
     def test_secret_create_defaults_bad_content_type_check_message(self):
@@ -515,11 +512,11 @@ class SecretsTestCase(base.TestCase):
         # first, ensure that the return code is 400
         self.assertEqual(400, resp.status_code)
 
-        resp_dict = json.loads(resp.content)
+        resp_dict = jsonutils.loads(resp.content)
 
         self.assertIn(
             "Provided object does not match schema 'Secret': "
-            "payload_content_type plain-text is not one of ['text/plain', "
+            "payload_content_type is not one of ['text/plain', "
             "'text/plain;charset=utf-8', 'text/plain; charset=utf-8', "
             "'application/octet-stream'", resp_dict['description'])
         self.assertIn("Bad Request", resp_dict['title'])
@@ -642,11 +639,11 @@ class SecretsTestCase(base.TestCase):
     @testcase.attr('positive')
     def test_secret_create_with_valid_bit_length(self, bit_length):
         """Covers cases of creating secrets with valid bit lengths."""
-        byte_length = bit_length / 8
+        byte_length = bit_length // 8
         secret = bytearray(byte_length)
         for x in range(0, byte_length):
             secret[x] = x
-        secret64 = base64.b64encode(secret)
+        secret64 = oslo_base64.encode_as_bytes(secret)
 
         test_model = secret_models.SecretModel(
             **self.default_secret_create_data)
@@ -660,7 +657,7 @@ class SecretsTestCase(base.TestCase):
         'str_type': ['not-an-int'],
         'empty': [''],
         'blank': [' '],
-        'negative_maxint': [-sys.maxint],
+        'negative_maxint': [-sys.maxsize],
         'negative_one': [-1],
         'zero': [0]
     })
@@ -739,10 +736,10 @@ class SecretsTestCase(base.TestCase):
         self.assertEqual(200, get_resp.status_code)
 
         if payload_content_encoding == 'base64':
-            self.assertIn(test_model.payload,
-                          binascii.b2a_base64(get_resp.content))
+            self.assertEqual(test_model.payload,
+                             oslo_base64.encode_as_bytes(get_resp.content))
         else:
-            self.assertIn(test_model.payload, get_resp.content)
+            self.assertEqual(test_model.payload, get_resp.content)
 
     @utils.parameterized_dataset({
         'text_content_type_none_encoding': {
@@ -780,10 +777,10 @@ class SecretsTestCase(base.TestCase):
         self.assertEqual(200, get_resp.status_code)
 
         if payload_content_encoding == 'base64':
-            self.assertIn(test_model.payload,
-                          binascii.b2a_base64(get_resp.content))
+            self.assertEqual(test_model.payload,
+                             oslo_base64.encode_as_bytes(get_resp.content))
         else:
-            self.assertIn(test_model.payload, get_resp.content)
+            self.assertEqual(test_model.payload, get_resp.content)
 
     @utils.parameterized_dataset({
         'empty_content_type_and_encoding': {
@@ -885,8 +882,8 @@ class SecretsTestCase(base.TestCase):
         'array': [['boom']],
         'int': [123],
         'none': [None],
-        'bad_character': [unichr(0x0080)],
-        'bad_characters': [unichr(0x1111) + unichr(0xffff)]
+        'bad_character': [six.unichr(0x0080)],
+        'bad_characters': [six.unichr(0x1111) + six.unichr(0xffff)]
     })
     @testcase.attr('negative')
     def test_secret_create_defaults_invalid_payload(self, payload):
@@ -998,7 +995,7 @@ class SecretsTestCase(base.TestCase):
 
     @utils.parameterized_dataset({
         'symmetric': ['symmetric',
-                      base64.b64decode(
+                      oslo_base64.decode_as_bytes(
                           get_default_payload()),
                       get_default_data()],
         'private': ['private',
@@ -1011,7 +1008,7 @@ class SecretsTestCase(base.TestCase):
                         keys.get_certificate_pem(),
                         get_certificate_req()],
         'passphrase': ['passphrase',
-                       'mysecretpassphrase',
+                       b'mysecretpassphrase',
                        get_passphrase_req()]
     })
     @testcase.attr('positive')
@@ -1090,7 +1087,15 @@ class SecretsTestCase(base.TestCase):
 
 
 @utils.parameterized_test_case
-class ListingSecretsTestCase(SecretsTestCase):
+class ListingSecretsTestCase(base.TestCase):
+
+    def setUp(self):
+        super(ListingSecretsTestCase, self).setUp()
+        self.behaviors = secret_behaviors.SecretBehaviors(self.client)
+
+    def tearDown(self):
+        self.behaviors.delete_all_created_secrets()
+        super(ListingSecretsTestCase, self).tearDown()
 
     @utils.parameterized_dataset({
         'query_by_name': {
@@ -1134,6 +1139,102 @@ class ListingSecretsTestCase(SecretsTestCase):
         self.assertEqual(200, resp.status_code)
         self.assertEqual(1, len(secrets_list))
 
+    @utils.parameterized_dataset({
+        'created': {
+            'date_type': 'created',
+        },
+        'updated': {
+            'date_type': 'updated',
+        },
+        'expiration': {
+            'date_type': 'expiration',
+        },
+    })
+    @testcase.attr('positive')
+    def test_secret_list_with_date_filter(self, date_type):
+        expiration_1 = str(
+            datetime.datetime.utcnow() + datetime.timedelta(days=3))
+        expiration_2 = str(
+            datetime.datetime.utcnow() + datetime.timedelta(days=5))
+
+        two_phase_model = secret_models.SecretModel(expiration=expiration_1)
+        resp, secret_ref_1 = self.behaviors.create_secret(two_phase_model)
+        # Assert that the secret metadata was created successfully
+        self.assertEqual(201, resp.status_code)
+        payload = "gF6+lLoF3ohA9aPRpt+6bQ=="
+        payload_content_type = "application/octet-stream"
+        payload_content_encoding = "base64"
+        update_resp = self.behaviors.update_secret_payload(
+            secret_ref_1, payload=payload,
+            payload_content_type=payload_content_type,
+            payload_content_encoding=payload_content_encoding)
+        # Assert that the secret payload was uploaded successfully
+        self.assertEqual(204, update_resp.status_code)
+
+        time.sleep(1)
+        model = secret_models.SecretModel(expiration=expiration_2)
+        resp, secret_ref_2 = self.behaviors.create_secret(model)
+
+        resp_1 = self.behaviors.get_secret_metadata(secret_ref_1)
+        resp_2 = self.behaviors.get_secret_metadata(secret_ref_2)
+
+        time_to_search_1 = getattr(resp_1.model, date_type)
+        time_to_search_2 = getattr(resp_2.model, date_type)
+
+        # Search for secrets with secret 1's time
+        query_dict = {date_type: time_to_search_1}
+
+        resp, secrets_list, next_ref, prev_ref = self.behaviors.get_secrets(
+            **query_dict)
+
+        self.assertEqual(200, resp.status_code)
+        self.assertEqual(1, len(secrets_list))
+        self.assertEqual(secret_ref_1, secrets_list[0].secret_ref)
+
+        # Search for secrets with time < secret 2, i.e. secret 1
+        query_dict = {date_type: 'lt:' + time_to_search_2}
+
+        resp, secrets_list, next_ref, prev_ref = self.behaviors.get_secrets(
+            **query_dict)
+
+        self.assertEqual(200, resp.status_code)
+        self.assertEqual(1, len(secrets_list))
+        self.assertEqual(secret_ref_1, secrets_list[0].secret_ref)
+
+        # Search for secrets with time <= secret 2, i.e. both secrets
+        query_dict = {date_type: 'lte:' + time_to_search_2,
+                      'sort': date_type + ':asc'}
+
+        resp, secrets_list, next_ref, prev_ref = self.behaviors.get_secrets(
+            **query_dict)
+
+        self.assertEqual(200, resp.status_code)
+        self.assertEqual(2, len(secrets_list))
+        self.assertEqual(secret_ref_1, secrets_list[0].secret_ref)
+        self.assertEqual(secret_ref_2, secrets_list[1].secret_ref)
+
+        # Search for secrets with time > secret 1, i.e. secret 2
+        query_dict = {date_type: 'gt:' + time_to_search_1}
+
+        resp, secrets_list, next_ref, prev_ref = self.behaviors.get_secrets(
+            **query_dict)
+
+        self.assertEqual(200, resp.status_code)
+        self.assertEqual(1, len(secrets_list))
+        self.assertEqual(secret_ref_2, secrets_list[0].secret_ref)
+
+        # Search for secrets with time >= secret 1, i.e. both secrets
+        query_dict = {date_type: 'gte:' + time_to_search_1,
+                      'sort': date_type + ':asc'}
+
+        resp, secrets_list, next_ref, prev_ref = self.behaviors.get_secrets(
+            **query_dict)
+
+        self.assertEqual(200, resp.status_code)
+        self.assertEqual(2, len(secrets_list))
+        self.assertEqual(secret_ref_1, secrets_list[0].secret_ref)
+        self.assertEqual(secret_ref_2, secrets_list[1].secret_ref)
+
 
 class SecretsPagingTestCase(base.PagingTestCase):
 
@@ -1180,7 +1281,7 @@ class SecretsUnauthedTestCase(base.TestCase):
 
         stored_auth = self.client._auth[
             self.client._default_user_name].stored_auth
-        project_id = stored_auth.values()[0]['project_id']
+        project_id = list(stored_auth.values())[0]['project_id']
         self.project_id_header = {
             'X-Project-Id': project_id
         }
@@ -1532,7 +1633,7 @@ class SecretsMultipleBackendTestCase(base.TestCase):
         'symmetric_type_preferred_store': [
             admin_a,
             'symmetric',
-            base64.b64decode(get_default_payload()),
+            oslo_base64.decode_as_bytes(get_default_payload()),
             get_default_data()
             ],
         'private_type_preferred_store': [
@@ -1562,7 +1663,7 @@ class SecretsMultipleBackendTestCase(base.TestCase):
         'symmetric_type_no_preferred_store': [
             admin_b,
             'symmetric',
-            base64.b64decode(get_default_payload()),
+            oslo_base64.decode_as_bytes(get_default_payload()),
             get_default_data()
             ],
         'private_type_no_preferred_store': [
@@ -1586,7 +1687,7 @@ class SecretsMultipleBackendTestCase(base.TestCase):
         'passphrase_type_no_preferred_store': [
             admin_b,
             'passphrase',
-            'mysecretpassphrase',
+            b'mysecretpassphrase',
             get_passphrase_req()
             ],
     })
